# Change log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

This document follows the conventions laid out in [Keep a CHANGELOG][keep].

## [0.1.0] - 2016-05-25
This is the first BETA release :smile:

You can now visualize VCFs/GEMINI dbs automatically by just pointing to a directory. It will build a SQLite database in the background to enable things like comments, gene lists, etc.

There's support for both SNV and SV analysis. VEP and SnpEff are specifically supported. There's a range of filters to apply to the variants.


[keep]: http://keepachangelog.com/
